#!/usr/bin/env python3
# -*- coding: utf-8 -*-

# DEUTSCHE VERSION
# test_agi_de.py für Asterisk
# Dieses Skript ruft Daten vom Kostal-Wechselrichter ab und gibt sie per AGI aus.
# Es benötigt kostal_modbusquery.py im selben Verzeichnis.

import asterisk_agi as agi  # AGI-Module importieren
from kostal_modbusquery import kostal_modbusquery  # Kostal-Modul importieren

def main():
    # Initialisiert die AGI-Umgebung
    env = agi.init_env()

    # Kostal-Daten abrufen
    try:
        Kostalquery = kostal_modbusquery()  # Initialisiert die Kostal-Abfrage
        Kostalquery.run()  # Führt die Abfrage aus

        # Daten berechnen
        KostalVal = {elements[1]: elements[3] for elements in Kostalquery.KostalRegister}  # Dictionary erstellen
        TotalHomeconsumption = round(
            KostalVal['Home own consumption from battery'] +
            KostalVal['Home own consumption from grid'] +
            KostalVal['Home own consumption from PV'], 1
        )
        LeftSidePowerGeneration = round((KostalVal['Power DC1'] + KostalVal['Power DC2']), 1)
        BatteryCharge = round(KostalVal['Battery voltage'] * KostalVal['Actual battery charge -minus or discharge -plus current'], 1)
        # PowertoGrid = round(KostalVal['Inverter Generation Power (actual)'] - TotalHomeconsumption, 1)
        PowertoGrid = round(
            KostalVal['Active power phase 1 (powermeter)'] +
            KostalVal['Active power phase 2 (powermeter)'] +
            KostalVal['Active power phase 3 (powermeter)'], 1
        )


        # Abspielen der Ergebnisse
        agi.sayit("/usr/share/asterisk/sounds/de/eigene/kostal/1.Leistungsbedarf_G711.org_")  # Hausverbrauch
        agi.saynumber(TotalHomeconsumption)  # Gesamtverbrauch ausgeben
        
        agi.sayit("/usr/share/asterisk/sounds/de/eigene/kostal/2.Ladezustand_G711.org_") 
        agi.saynumber(KostalVal['Act. state of charge'])
        
        agi.sayit("/usr/share/asterisk/sounds/de/eigene/kostal/3.Temperatur_G711.org_") 
        agi.saynumber(KostalVal['Battery temperature'])
        
        agi.sayit("/usr/share/asterisk/sounds/de/eigene/kostal/4.Leistung_Solar_G711.org_") 
        agi.saynumber(LeftSidePowerGeneration)
        
        agi.sayit("/usr/share/asterisk/sounds/de/eigene/kostal/5.Ladeleistung_G711.org_") 
        agi.saynumber(BatteryCharge)
        
        # Ansage für Netzbezug oder Einspeisung
        if PowertoGrid > 0:                 # Wenn PowertoGrid größer Null, dann Netzbezug
            agi.sayit("/usr/share/asterisk/sounds/de/eigene/kostal/netzbezug_G711.org_")  # Netzbezug
        else:                               # andernfalls ist der Betrag von PowertoGrid die Netzeinspeisung
            PowertoGrid = abs(PowertoGrid)  # Betrag für Einspeisung verwenden
            agi.sayit("/usr/share/asterisk/sounds/de/eigene/kostal/einspeisung_G711.org_")  # Einspeisung
        
        agi.saynumber(PowertoGrid)
        agi.sayit("/usr/share/asterisk/sounds/de/eigene/kostal/watt_G711.org_")  # Watt

        
        agi.sayit("/usr/share/asterisk/sounds/de/eigene/kostal/7.Ende_Durchsage_G711.org_") 


    except Exception as ex:
        agi.sayit("/usr/share/asterisk/sounds/de/eigene/kostal/8.Fehler_G711.org_")
        agi.verbose(f"Error: {str(ex)}", level=3)  # Fehler im Asterisk-Log anzeigen

if __name__ == "__main__":
    main()

